summaryrefslogtreecommitdiff
path: root/src/VBox/Devices/VMMDev/VMMDevState.h
diff options
context:
space:
mode:
authorvboxsync <vboxsync@cfe28804-0f27-0410-a406-dd0f0b0b656f>2022-12-13 13:06:03 +0000
committervboxsync <vboxsync@cfe28804-0f27-0410-a406-dd0f0b0b656f>2022-12-13 13:06:03 +0000
commit052943bd62b6a951b825f5558a295815438d68b2 (patch)
tree927c3556146a65abfee80b6f8243aecd0adb6cc5 /src/VBox/Devices/VMMDev/VMMDevState.h
parent6d66ccb28908fac4d88bd73cefb01892ab7b026e (diff)
downloadVirtualBox-svn-052943bd62b6a951b825f5558a295815438d68b2.tar.gz
VMMDev mouse: bugref:10285: Introduce extended host mouse pointer state.
Provide VMMDev mouse with buttons and H/V wheel movement state. Extended state can be now fetched from host in scope of VMMDevReqMouseStatusEx request. Currently only Linux Additions utilize this functionality. git-svn-id: https://www.virtualbox.org/svn/vbox/trunk@97790 cfe28804-0f27-0410-a406-dd0f0b0b656f
Diffstat (limited to 'src/VBox/Devices/VMMDev/VMMDevState.h')
-rw-r--r--src/VBox/Devices/VMMDev/VMMDevState.h9
1 files changed, 7 insertions, 2 deletions
diff --git a/src/VBox/Devices/VMMDev/VMMDevState.h b/src/VBox/Devices/VMMDev/VMMDevState.h
index 112852dbfba..c4a959f1996 100644
--- a/src/VBox/Devices/VMMDev/VMMDevState.h
+++ b/src/VBox/Devices/VMMDev/VMMDevState.h
@@ -144,10 +144,13 @@ typedef struct VMMDEV
/** mouse capabilities of host and guest */
uint32_t fMouseCapabilities;
/** @name Absolute mouse position in pixels
* @{ */
int32_t xMouseAbs;
int32_t yMouseAbs;
+ int32_t dzMouse;
+ int32_t dwMouse;
+ uint32_t fMouseButtons;
/** @} */
/** Does the guest currently want the host pointer to be shown? */
uint32_t fHostCursorRequested;
@@ -563,7 +566,9 @@ void VMMDevCtlSetGuestFilterMask(PPDMDEVINS pDevIns, PVMMDEV pThis, PVMMDEVCC pT
/** The saved state version. */
-#define VMMDEV_SAVED_STATE_VERSION VMMDEV_SAVED_STATE_VERSION_DISPLAY_CHANGE_DATA
+#define VMMDEV_SAVED_STATE_VERSION VMMDEV_SAVED_STATE_VERSION_VMM_MOUSE_EXTENDED_DATA
+/** The saved state version with VMMDev mouse buttons state and wheel movement data. */
+#define VMMDEV_SAVED_STATE_VERSION_VMM_MOUSE_EXTENDED_DATA 19
/** The saved state version with display change data state. */
#define VMMDEV_SAVED_STATE_VERSION_DISPLAY_CHANGE_DATA 18
/** Updated HGCM commands. */
@@ -144,10 +144,13 @@ typedef struct VMMDEV
/** mouse capabilities of host and guest */
uint32_t fMouseCapabilities;
- /** @name Absolute mouse position in pixels
+ /** @name Absolute mouse position in pixels, relative wheel movement and buttons state.
* @{ */
int32_t xMouseAbs;